sleepguard package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   sleepguard.monitors
   sleepguard.resources

Submodules
----------

sleepguard.guard module
-----------------------

.. automodule:: sleepguard.guard
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: sleepguard
   :members:
   :undoc-members:
   :show-inheritance:
